@@ -147,7 +147,8 @@ class LogicRow:
                     result += value
                 else:
                     result += str(value)
-        result += f'  row@: {str(hex(id(self.row)))}'
+        result += f'  row: {str(hex(id(self.row)))}'
+        result += f'  session: {str(hex(id(self.session)))}'
         return result  # str(my_dict)
 
     def log(self, msg: str) -> str:
@@ -229,22 +230,12 @@ class LogicRow:
 
     def early_row_events(self):
         self.log_engine("early_events")
-        """
-        early_row_events = rule_bank_withdraw.generic_rules_of_class(EarlyRowEvent)  # FIXME - review duplication
-        for each_row_event in early_row_events:
-            each_row_event.execute(self)
-        """
         early_row_events = rule_bank_withdraw.rules_of_class(self, EarlyRowEvent)
         for each_row_event in early_row_events:
             each_row_event.execute(self)
 
     def row_events(self):
-        self.log_engine("early_events")
-        """
-        early_row_events = rule_bank_withdraw.generic_rules_of_class(EarlyRowEvent)  # FIXME - review duplication
-        for each_row_event in early_row_events:
-            each_row_event.execute(self)
-        """
+        self.log_engine("row_events")
         row_events = rule_bank_withdraw.rules_of_class(self, RowEvent)
         for each_row_event in row_events:
             each_row_event.execute(self)
@@ -467,6 +458,7 @@ class LogicRow:
         row_mapper = object_mapper(self.row)
         if self.row.__tablename__ == "Customerxx":
             print("Debug Stop here")
+            # TODO - check use of LogicRow (using row_mapper.column_attrs??  vs attrs)
         from_attrs = object_mapper(from_logic_row.row).column_attrs
         for each_attr in row_mapper.column_attrs:  # avoid parent objects, child collections
             is_hybrid = isinstance(each_attr, hybrid_property)
@@ -664,10 +656,12 @@ class LogicRow:
             if each_relationship.direction == sqlalchemy.orm.interfaces.MANYTOONE:  # cust, emp
                 parent_role_name = each_relationship.key  # eg, OrderList
                 if self.is_foreign_key_null(each_relationship) is False:
-                    # continue
+                    # continue - foreign key not null - parent *should* exist
                     self.get_parent_logic_row(parent_role_name)  # sets the accessor
                     does_parent_exist = getattr(self.row, parent_role_name)
-                    if does_parent_exist is None and ref_integ_enabled:
+                    if does_parent_exist:
+                        pass  # yes, parent exists... it's all fine
+                    elif ref_integ_enabled:
                         msg = "Missing Parent: " + parent_role_name
                         self.log(msg)
                         ll = RuleBank()
